# Confluence changelog

## [0.1.1] - 2026-03-11
- Updated connector definition (YAML version 1.0.0)
- Source commit: 44677ecb
- SDK version: 0.1.0

## [0.1.0] - 2026-03-05
- Updated connector definition (YAML version 1.0.0)
- Source commit: e50d6dd2
- SDK version: 0.1.0
